/*
 * FILE: DailyFibos_v0.1_CHT.mq4
 * AUTHOR: Thierry Chappuis <tc77@pygnol.ch>
 * DESCRIPTION:
 * MT4 Custom indicator to automatically draw a complete sequence of
 * daily fibonacci SR on a candlestick chart.
 *
 * LOG:
 * - 20121119: first version
 *
 * Copyright 2012, Thierry Chappuis
 */

#property copyright "Copyright 2012, Thierry Chappuis"
#property link      "tc77@pygnol.ch"

#property indicator_chart_window

extern color FiboColor = Orange;
extern color FiboRetColor = Yellow;
extern color FiboExtColor = Aqua;

extern bool AlertON = false;
extern double AlertDistance = 20;

double NB_LEVELS = 21;
double levels[21];
double fibos[21] =
{
    0.0,
    1.0,
    0.114,
    0.236,
    0.298,
    0.382,
    0.500,
    0.618,
    0.702,
    0.764,
    0.886,
    1.272,
    1.382,
    1.618,
    1.786,
    2.000,
    2.618,
    -0.272,
    -0.382,
    -0.618,
    -0.786,
    -1.000,
    -1.618,
};
string labels[21] =
{
    "0.0",
    "100.0",
    "11.4",
    "23.6",
    "29.8",
    "38.2",
    "50.0 ",
    "61.8",
    "70.2",
    "76.4",
    "88.6",
    "127.2",
    "138.2",
    "161.8",
    "178.6",
    "200.0",
    "261.8",
    "-127.2",
    "-138.2",
    "-161.8",
    "-178.6",
    "-200.0",
    "-261.8",
};

bool in[21];

int init()
{
    for (int i = 0; i < NB_LEVELS; i++)
    {
        in[i] = false;
    }

    Comment("DailyFibos");
    return(0);
}

int start()
{
    double previous_day_low;
    double previous_day_high;
    color col;
    int style;

    previous_day_high = iHigh(NULL, PERIOD_D1, 1);
    previous_day_low = iLow(NULL, PERIOD_D1, 1);

    if(DayOfWeek() == 1) // If last know server day is Monday
    {
        for(int day = 1; day < 7; day++)
        {
            if(TimeDayOfWeek(iTime(NULL,PERIOD_D1, day)) == 5)
            {

                previous_day_high = iHigh(NULL, PERIOD_D1, day);
                previous_day_low = iLow(NULL, PERIOD_D1, day);
            }
        }
    }

    double range = previous_day_high - previous_day_low;

    for (int i = 0; i < NB_LEVELS; i++)
    {
        style = 0;
        col = FiboRetColor;

        levels[i] = previous_day_low + range * fibos[i];

        if (labels[i] == "0.0" || labels[i] == "100.0" ||
                labels[i] == "161.8" || labels[i] == "-161.8")
        {
            col = FiboColor;
            style = 1;
        }

        if (fibos[i] < 0.0 || fibos[i] > 1.0)
        {
            col = FiboExtColor;
        }

        cht_draw_line(levels[i], "ID Level " + labels[i], col, style);
        cht_draw_label(levels[i], "Level " + labels[i], col);
    }


    if (AlertON == true)
    {
        cht_alarm();
    }

    Comment("DailyFibos (H: " + previous_day_high + " / L: " + previous_day_low + ")");

    return(0);
}

int deinit()
{
    for (int i = 0; i < NB_LEVELS; i++)
    {
        ObjectDelete("ID Level " + labels[i]);
        ObjectDelete("Level " + labels[i]);
    }

    Comment("");

    return(0);
}

bool cht_alarm()
{
    for (int i = 0; i < NB_LEVELS; i++)
    {
        if (Close[0] > levels[i]-AlertDistance*Point &&
                Close[0] < levels[i]+AlertDistance*Point  &&
                in[i] == false)
        {
            in[i] = true;
            Alert(Symbol(), " (", Period(), "min): price approaches level ", labels[i], "!");
        }

        if (Close[0] < levels[i]-AlertDistance*Point &&
                Close[0] < levels[i]+AlertDistance*Point  &&
                in[i] == true)
        {
            in[i] = false;
        }
    }
    return(false);
}

void cht_draw_label(double level, string name, color col)
{
    int first_bar = WindowFirstVisibleBar();

    if(ObjectFind(name) != 0)
    {
        ObjectCreate(name, OBJ_TEXT, 0, Time[first_bar-5], level);
        ObjectSetText(name, name, 6, "Arial", EMPTY);
        ObjectSet(name, OBJPROP_COLOR, col);
    }
    else
    {
        ObjectMove(name, 0, Time[first_bar-5], level);
    }
}


void cht_draw_line(double level, string name, color col, int style)
{
    if(ObjectFind(name) == 0)
    {
        ObjectDelete(name);
    }

    ObjectCreate(name, OBJ_HLINE, 0, Time[0], level, Time[0], level);


    ObjectSet(name, OBJPROP_STYLE, STYLE_DOT);
    ObjectSet(name, OBJPROP_COLOR, col);
    ObjectSet(name, OBJPROP_WIDTH, 1);

    if (style == 1)
    {
        ObjectSet(name, OBJPROP_STYLE, STYLE_SOLID);
        ObjectSet(name, OBJPROP_WIDTH, 2);
    }
}

